From 716d7881728f55b4405aab53b654c851993b7fef Mon Sep 17 00:00:00 2001
From: Thomas Munro <thomas.munro@enterprisedb.com>
Date: Fri, 2 Nov 2018 14:42:10 +1300
Subject: [PATCH] Fix bug in multi-batch Parallel Hash Left Join.

Due to a thinko in 1804284042e, NULL keys in left joins were not
handled correctly when partitioning the outer (left) relation.
Repair.  Bug #15475.  Back-patch to 11.

Reported-by: Paul Schaap
Diagnosed-by: Andrew Gierth
Dicussion: https://postgr.es/m/15475-11a7a783fed72a36%40postgresql.org
---
 src/backend/executor/nodeHashjoin.c | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/src/backend/executor/nodeHashjoin.c b/src/backend/executor/nodeHashjoin.c
index dd94cffbd18..5922e60eed6 100644
--- a/src/backend/executor/nodeHashjoin.c
+++ b/src/backend/executor/nodeHashjoin.c
@@ -1395,7 +1395,7 @@ ExecParallelHashJoinPartitionOuter(HashJoinState *hjstate)
 		if (ExecHashGetHashValue(hashtable, econtext,
 								 hjstate->hj_OuterHashKeys,
 								 true,	/* outer tuple */
-								 false, /* outer join, currently unsupported */
+								 HJ_FILL_OUTER(hjstate),
 								 &hashvalue))
 		{
 			int			batchno;
-- 
2.19.1

